@@ -43,6 +43,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <KMimeType>
 #include <KProtocolInfo>
 #include <KUrl>
+#include <libkdcraw/kdcraw.h>
 
 // Local
 #include "animateddocumentloadedimpl.h"
@@ -73,6 +74,8 @@ namespace Gwenview
 #define LOG(x) ;
 #endif
 
+const int MIN_PREV_SIZE = 1000;
+
 const int HEADER_SIZE = 256;
 
 struct LoadingDocumentImplPrivate
@@ -182,32 +185,68 @@ struct LoadingDocumentImplPrivate
 
     bool loadMetaInfo()
     {
+        LOG("mFormatHint" << mFormatHint);
         QBuffer buffer;
         buffer.setBuffer(&mData);
         buffer.open(QIODevice::ReadOnly);
-        LOG("mFormatHint" << mFormatHint);
-        QImageReader reader(&buffer, mFormatHint);
-        if (!reader.canRead()) {
-            kWarning() << "QImageReader::read() using format hint" << mFormatHint << "failed:" << reader.errorString();
-            if (buffer.pos() != 0) {
-                kWarning() << "A bad Qt image decoder moved the buffer to" << buffer.pos() << "in a call to canRead()! Rewinding.";
-                buffer.seek(0);
+
+        if (KDcrawIface::KDcraw::rawFilesList().contains(QString(mFormatHint))) {
+            QByteArray previewData;
+
+            // if the image is in format supported by dcraw, fetch its embedded preview
+            mJpegContent.reset(new JpegContent());
+
+            // use KDcraw for getting the embedded preview
+            // KDcraw functionality cloned locally (temp. solution)
+            bool ret = KDcrawIface::KDcraw::loadEmbeddedPreview(previewData, buffer);
+
+            QImage originalImage;
+            if (!ret || !originalImage.loadFromData(previewData) || qMin(originalImage.width(), originalImage.height()) < MIN_PREV_SIZE) {
+                // if the embedded preview loading failed or gets just a small image, load
+                // half preview instead. That's slower but it works even for images containing
+                // small (160x120px) or none embedded preview.
+                if (!KDcrawIface::KDcraw::loadHalfPreview(previewData, buffer)) {
+                    kWarning() << "unable to get half preview for " << q->document()->url().fileName();
+                    return false;
+                }
             }
-            reader.setFormat(QByteArray());
-            // Set buffer again, otherwise QImageReader won't restart from scratch
-            reader.setDevice(&buffer);
+
+            buffer.close();
+
+            // now it's safe to replace mData with the jpeg data
+            mData = previewData;
+
+            // need to fill mFormat so gwenview can tell the type when trying to save
+            mFormat = mFormatHint;
+        } else {
+            QImageReader reader(&buffer, mFormatHint);
+            mImageSize = reader.size();
+
             if (!reader.canRead()) {
-                kWarning() << "QImageReader::read() without format hint failed:" << reader.errorString();
-                return false;
+                kWarning() << "QImageReader::read() using format hint" << mFormatHint << "failed:" << reader.errorString();
+                if (buffer.pos() != 0) {
+                    kWarning() << "A bad Qt image decoder moved the buffer to" << buffer.pos() << "in a call to canRead()! Rewinding.";
+                    buffer.seek(0);
+                }
+                reader.setFormat(QByteArray());
+                // Set buffer again, otherwise QImageReader won't restart from scratch
+                reader.setDevice(&buffer);
+                if (!reader.canRead()) {
+                    kWarning() << "QImageReader::read() without format hint failed:" << reader.errorString();
+                    return false;
+                }
+                kWarning() << "Image format is actually" << reader.format() << "not" << mFormatHint;
+            }
+
+            mFormat = reader.format();
+
+            if (mFormat == "jpg") {
+                // if mFormatHint was "jpg", then mFormat is "jpg", but the rest of
+                // Gwenview code assumes JPEG images have "jpeg" format.
+                mFormat = "jpeg";
             }
-            kWarning() << "Image format is actually" << reader.format() << "not" << mFormatHint;
-        }
-        mFormat = reader.format();
-        if (mFormat == "jpg") {
-            // if mFormatHint was "jpg", then mFormat is "jpg", but the rest of
-            // Gwenview code assumes JPEG images have "jpeg" format.
-            mFormat = "jpeg";
         }
+
         LOG("mFormat" << mFormat);
         GV_RETURN_VALUE_IF_FAIL(!mFormat.isEmpty(), false);
 
@@ -218,18 +257,22 @@ struct LoadingDocumentImplPrivate
 
         if (mFormat == "jpeg" && mExiv2Image.get()) {
             mJpegContent.reset(new JpegContent());
-            if (!mJpegContent->loadFromData(mData, mExiv2Image.get())) {
+        }
+
+        if (mJpegContent.get()) {
+            if (!mJpegContent->loadFromData(mData, mExiv2Image.get()) &&
+                !mJpegContent->loadFromData(mData)) {
+                kWarning() << "Unable to use preview of " << q->document()->url().fileName();
                 return false;
             }
-
             // Use the size from JpegContent, as its correctly transposed if the
             // image has been rotated
             mImageSize = mJpegContent->size();
 
             mCmsProfile = Cms::Profile::loadFromExiv2Image(mExiv2Image.get());
-        } else {
-            mImageSize = reader.size();
+
         }
+
         LOG("mImageSize" << mImageSize);
 
         if (!mCmsProfile) {
